@@ -26,7 +26,7 @@
 #define DH_BITS 1024
 
 /* These are global */
-gnutls_certificate_credentials x509_cred;
+gnutls_certificate_credentials cert_cred;
 
 static void wrap_db_init(void);
 static void wrap_db_deinit(void);
@@ -46,7 +46,7 @@ gnutls_session initialize_tls_session()
     */
    gnutls_set_default_export_priority(session);
 
-   gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, x509_cred);
+   gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, cert_cred);
 
    /* request client certificate if any.
     */
@@ -117,15 +117,15 @@ int main()
     */
    gnutls_global_init();
 
-   gnutls_certificate_allocate_credentials(&x509_cred);
+   gnutls_certificate_allocate_credentials(&cert_cred);
 
-   gnutls_certificate_set_x509_trust_file(x509_cred, CAFILE,
+   gnutls_certificate_set_x509_trust_file(cert_cred, CAFILE,
                                           GNUTLS_X509_FMT_PEM);
 
-   gnutls_certificate_set_x509_crl_file(x509_cred, CRLFILE,
+   gnutls_certificate_set_x509_crl_file(cert_cred, CRLFILE,
                                           GNUTLS_X509_FMT_PEM);
 
-   gnutls_certificate_set_x509_key_file(x509_cred, CERTFILE, KEYFILE,
+   gnutls_certificate_set_x509_key_file(cert_cred, CERTFILE, KEYFILE,
                                         GNUTLS_X509_FMT_PEM);
 
    generate_dh_params();
@@ -135,8 +135,8 @@ int main()
       wrap_db_init();
    }
 
-   gnutls_certificate_set_dh_params(x509_cred, dh_params);
-   gnutls_certificate_set_rsa_export_params(x509_cred, rsa_params);
+   gnutls_certificate_set_dh_params(cert_cred, dh_params);
+   gnutls_certificate_set_rsa_export_params(cert_cred, rsa_params);
 
    /* Socket operations
     */
@@ -210,7 +210,7 @@ int main()
    }
    close(listen_sd);
 
-   gnutls_certificate_free_credentials(x509_cred);
+   gnutls_certificate_free_credentials(cert_cred);
 
    gnutls_global_deinit();
 
