@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2002,2003 Nikos Mavroyanopoulos
+ * Copyright (C) 2004 Free Software Foundation
  *
  * This file is part of GNUTLS.
  *
@@ -30,6 +31,9 @@
 #include <gnutls_state.h>
 #include <gnutls_num.h>
 
+inline static int _gnutls_num2cert_type( int num);
+inline static int _gnutls_cert_type2num( int record_size);
+
 /* 
  * In case of a server: if a CERT_TYPE extension type is received then it stores
  * into the session security parameters the new value. The server may use gnutls_session_certificate_type_get(),
@@ -89,7 +93,7 @@ int _gnutls_cert_type_recv_params( gnutls_session session, const opaque* data, s
 			
 			if (new_type < 0) {
 				gnutls_assert();
-				return GNUTLS_E_RECEIVED_ILLEGAL_PARAMETER;
+				return 0;
 			}
 
 			if ( (ret=_gnutls_session_cert_type_supported( session, new_type)) < 0) {
@@ -144,7 +148,6 @@ int _gnutls_cert_type_send_params( gnutls_session session, opaque* data, size_t
 		}
 
 	} else { /* server side */
-
 		if ( session->security_parameters.cert_type != DEFAULT_CERT_TYPE) {
 			len = 1;
 			if (data_size < len) {
@@ -165,7 +168,8 @@ int _gnutls_cert_type_send_params( gnutls_session session, opaque* data, size_t
 /* Maps numbers to record sizes according to the
  * extensions draft.
  */
-int _gnutls_num2cert_type( int num) {
+inline
+static int _gnutls_num2cert_type( int num) {
 	switch( num) {
 	case 0:
 		return GNUTLS_CRT_X509;
@@ -179,7 +183,8 @@ int _gnutls_num2cert_type( int num) {
 /* Maps record size to numbers according to the
  * extensions draft.
  */
-int _gnutls_cert_type2num( int cert_type) {
+inline
+static int _gnutls_cert_type2num( int cert_type) {
 	switch(cert_type) {
 	case GNUTLS_CRT_X509:
 		return 0;
